@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: zipconv.c,v $
- * $Revision: 1.24 $
- * $Date: 2013/09/04 11:33:55 $
+ * $Revision: 1.25 $
+ * $Date: 2014/05/09 04:43:07 $
  */
 
 #include <stdio.h>
@@ -105,7 +105,9 @@ mailzip_clean(struct mailzip mz)
     }
 
     if (mz.date != NULL) {
-	free(mz.date);
+//        free(mz.date);
+        /* Repairing The display of the date 2014/05/08 (Thu) */
+        g_free(mz.date);
     }
 
     if (mz.encfilepath != NULL) {
@@ -664,8 +666,15 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 
     /* Get header subject */
     mz->subject = g_mime_message_get_subject(mz->message);
+
     /* Get header date */
-    mz->date = g_mime_message_get_date_string(mz->message);
+    if (cfg->cf_settimezone == 0) {
+        mz->date = g_mime_message_get_date_string(mz->message);
+    } else {
+        /* Repairing The display of the date 2014/05/08 (Thu) */
+        mz->date =  g_mime_utils_header_format_date (mz->message->date,
+                                                     cfg->cf_settimezone);
+    }
 
     /* gmime part object */
     object = g_mime_message_get_mime_part(mz->message);
